Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(552)

Unified Diff: components/sync_driver/glue/sync_backend_host_impl.h

Issue 2087583002: Remove calls to MessageLoop::current() in components. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix test error Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync_driver/glue/sync_backend_host_impl.h
diff --git a/components/sync_driver/glue/sync_backend_host_impl.h b/components/sync_driver/glue/sync_backend_host_impl.h
index d9a3da492dbc59a987b21c64c377646f8e42b800..d0c48f255be9c4f723aa3ed13705034e29db88f3 100644
--- a/components/sync_driver/glue/sync_backend_host_impl.h
+++ b/components/sync_driver/glue/sync_backend_host_impl.h
@@ -15,7 +15,9 @@
#include "base/callback.h"
#include "base/compiler_specific.h"
#include "base/macros.h"
+#include "base/memory/ref_counted.h"
#include "base/memory/weak_ptr.h"
+#include "base/single_thread_task_runner.h"
#include "base/threading/thread.h"
#include "components/invalidation/public/invalidation_handler.h"
#include "components/sync_driver/backend_data_type_configurer.h"
@@ -318,9 +320,9 @@ class SyncBackendHostImpl
void ClearServerDataDoneOnFrontendLoop(
const syncer::SyncManager::ClearServerDataCallback& frontend_callback);
- // A reference to the MessageLoop used to construct |this|, so we know how
- // to safely talk back to the SyncFrontend.
- base::MessageLoop* const frontend_loop_;
+ // A reference to the TaskRUnner used to construct |this|, so we know how to
+ // safely talk back to the SyncFrontend.
+ scoped_refptr<base::SingleThreadTaskRunner> const frontend_task_runner_;
sync_driver::SyncClient* const sync_client_;
« no previous file with comments | « components/sync_driver/glue/sync_backend_host_core.cc ('k') | components/sync_driver/glue/sync_backend_host_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698